@@ -49,6 +49,10 @@ int psb_init_yres;
 /*
  *
  */
+#define SII_1392_WA
+#ifdef SII_1392_WA
+extern int SII_1392;
+#endif
 
 MODULE_PARM_DESC(debug, "Enable debug output");
 MODULE_PARM_DESC(clock_gating, "clock gating");
@@ -264,6 +268,12 @@ static int psb_do_init(struct drm_device *dev)
 	if (!dev_priv->comm_page)
 		goto out_err;
 
+#if (LINUX_VERSION_CODE < KERNEL_VERSION(2,6,25))
+	change_page_attr(dev_priv->comm_page, 1, PAGE_KERNEL_NOCACHE);
+#else
+	map_page_into_agp(dev_priv->comm_page);
+#endif
+
 	dev_priv->comm = kmap(dev_priv->comm_page);
 	memset((void *)dev_priv->comm, 0, PAGE_SIZE);
 
@@ -304,8 +314,7 @@ static int psb_do_init(struct drm_device *dev)
 
 	ret = psb_mmu_insert_pages(psb_mmu_get_default_pd(dev_priv->mmu),
 				   &dev_priv->comm_page,
-				   dev_priv->comm_mmu_offset, 1, 0, 0,
-				   PSB_MMU_CACHED_MEMORY);
+				   dev_priv->comm_mmu_offset, 1, 0, 0, 0);
 
 	if (ret)
 		goto out_err;
@@ -380,6 +389,12 @@ static int psb_driver_unload(struct drm_device *dev)
 	struct drm_psb_private *dev_priv =
 	    (struct drm_psb_private *)dev->dev_private;
 
+#ifdef USE_PAT_WC
+#warning Init pat
+//	if (num_present_cpus() > 1)
+	unregister_cpu_notifier(&psb_nb);
+#endif
+
 	intel_modeset_cleanup(dev);
 
 	if (dev_priv) {
@@ -491,7 +506,13 @@ static int psb_initial_config(struct drm_device *dev, bool can_grow)
 					  output->crtc->desired_mode, 0, 0);
 	}
 
+#ifdef SII_1392_WA
+	if((SII_1392 != 1) || (drm_psb_no_fb==0))
+		drm_disable_unused_functions(dev);
+#else
 	drm_disable_unused_functions(dev);
+#endif
+
 
 	mutex_unlock(&dev->mode_config.mutex);
 
@@ -565,6 +586,12 @@ static int psb_driver_load(struct drm_device *dev, unsigned long chipset)
 	if (!dev_priv->scratch_page)
 		goto out_err;
 
+#if (LINUX_VERSION_CODE < KERNEL_VERSION(2,6,25))
+	change_page_attr(dev_priv->scratch_page, 1, PAGE_KERNEL_NOCACHE);
+#else
+	map_page_into_agp(dev_priv->scratch_page);
+#endif
+
 	dev_priv->pg = psb_gtt_alloc(dev);
 	if (!dev_priv->pg)
 		goto out_err;
@@ -648,6 +675,7 @@ static int psb_driver_load(struct drm_device *dev, unsigned long chipset)
 
 #ifdef USE_PAT_WC
 #warning Init pat
+//	if (num_present_cpus() > 1)
 	register_cpu_notifier(&psb_nb);
 #endif
 
@@ -715,15 +743,19 @@ static int psb_suspend(struct pci_dev *pdev, pm_message_t state)
 	    (struct drm_psb_private *)dev->dev_private;
         struct drm_output *output;
 
-	if (drm_psb_no_fb == 0)
-		psbfb_suspend(dev);
+	//if (drm_psb_no_fb == 0)
+	//	psbfb_suspend(dev);
 #ifdef WA_NO_FB_GARBAGE_DISPLAY
-	else {
-		list_for_each_entry(output, &dev->mode_config.output_list, head) {
-			if(output->crtc != NULL)
-				intel_crtc_mode_save(output->crtc);
-			//if(output->funcs->save)
-			//	output->funcs->save(output);
+	//else {
+	if (drm_psb_no_fb != 0) {
+		if(num_registered_fb)
+		{
+			list_for_each_entry(output, &dev->mode_config.output_list, head) {
+				if(output->crtc != NULL)
+					intel_crtc_mode_save(output->crtc);
+				//if(output->funcs->save)
+				//	output->funcs->save(output);
+			}
 		}
 	}
 #endif
@@ -765,6 +797,7 @@ static int psb_resume(struct pci_dev *pdev)
 	/* for single CPU's we do it here, then for more than one CPU we
 	 * use the CPU notifier to reinit PAT on those CPU's. 
 	 */
+//	if (num_present_cpus() == 1)
 	drm_init_pat();
 #endif
 
@@ -837,17 +870,18 @@ static int psb_resume(struct pci_dev *pdev)
 				    dev_priv->ta_mem->hw_cookie);
 	}
 
-	if (drm_psb_no_fb == 0)
-		psbfb_resume(dev);
+	//if (drm_psb_no_fb == 0)
+	//	psbfb_resume(dev);
 #ifdef WA_NO_FB_GARBAGE_DISPLAY
-	else { 
-		list_for_each_entry(output, &dev->mode_config.output_list, head) {
-			if(output->crtc != NULL)
-				intel_crtc_mode_restore(output->crtc);
-		}
+	//else {
+	if (drm_psb_no_fb != 0) {
 		if(num_registered_fb)
 		{
 			struct fb_info *fb_info=registered_fb[0];
+			list_for_each_entry(output, &dev->mode_config.output_list, head) {
+				if(output->crtc != NULL)
+					intel_crtc_mode_restore(output->crtc);
+			}
 			if(fb_info)
 			{
 				fb_set_suspend(fb_info, 0);
