@@ -38,6 +38,11 @@
 #include "psb_drv.h"
 #include "drm_compat.h"
 
+#define SII_1392_WA
+#ifdef SII_1392_WA
+extern int SII_1392;
+#endif
+
 struct psbfb_vm_info {
 	struct drm_buffer_object *bo;
 	struct address_space *f_mapping;
@@ -94,7 +99,7 @@ static int psbfb_setcolreg(unsigned regno, unsigned red, unsigned green,
 	if (!crtc->fb)
 		return -ENOMEM;
 
-	if (regno > 255)
+	if (regno > 15)
 		return 1;
 
 	if (crtc->funcs->gamma_set)
@@ -951,7 +956,12 @@ int psbfb_kms_on_ioctl(struct drm_device *dev, void *data,
 	acquire_console_sem();
 	ret = psbfb_kms_on(dev, 0);
 	release_console_sem();
+#ifdef SII_1392_WA
+	if((SII_1392 != 1) || (drm_psb_no_fb==0))
+		drm_disable_unused_functions(dev);
+#else
 	drm_disable_unused_functions(dev);
+#endif
 	return ret;
 }
 
@@ -967,7 +977,12 @@ void psbfb_resume(struct drm_device *dev)
 	acquire_console_sem();
 	psbfb_kms_on(dev, 1);
 	release_console_sem();
+#ifdef SII_1392_WA
+	if((SII_1392 != 1) || (drm_psb_no_fb==0))
+		drm_disable_unused_functions(dev);
+#else
 	drm_disable_unused_functions(dev);
+#endif
 }
 
 /*
@@ -1000,7 +1015,24 @@ static unsigned long psbfb_nopfn(struct vm_area_struct *vma,
 	mutex_unlock(&vi->vm_mutex);
 	return ret;
 }
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,27))
+static int psbfb_fault(struct vm_area_struct *vma,
+				 struct vm_fault *vmf)
+{
+	struct psbfb_vm_info *vi = (struct psbfb_vm_info *)vma->vm_private_data;
+	struct vm_area_struct tmp_vma;
+	unsigned long ret;
 
+        unsigned long address = (unsigned long)vmf->virtual_address;
+
+	mutex_lock(&vi->vm_mutex);
+	tmp_vma = *vma;
+	tmp_vma.vm_private_data = vi->bo;
+	ret = drm_bo_vm_nopfn(&tmp_vma, address);
+	mutex_unlock(&vi->vm_mutex);
+	return ret;
+}
+#endif
 static void psbfb_vm_open(struct vm_area_struct *vma)
 {
 	struct psbfb_vm_info *vi = (struct psbfb_vm_info *)vma->vm_private_data;
@@ -1014,8 +1046,11 @@ static void psbfb_vm_close(struct vm_area_struct *vma)
 }
 
 static struct vm_operations_struct psbfb_vm_ops = {
+  #if (LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,27))
+        .fault = psbfb_fault,
+  #else
 	.nopfn = psbfb_nopfn,
-	.nopage = NULL,
+  #endif
 	.open = psbfb_vm_open,
 	.close = psbfb_vm_close,
 };
